@@ -1,10 +1,9 @@
 package IRC::Toolkit;
 {
-  $IRC::Toolkit::VERSION = '0.087000';
+  $IRC::Toolkit::VERSION = '0.088001';
 }
-
-use Carp;
 use strictures 1;
+use Carp;
 
 ## Core bits can be added to this list ...
 ## ... but removing modules will break stuff downstream
@@ -24,12 +23,8 @@ sub import {
   my $pkg = caller;
   my @failed;
   for my $mod (@load) {
-    my $ld = "package $pkg; use IRC::Toolkit::$mod";
-    eval $ld;
-    if ($@) {
-      warn $@;
-      push @failed, $mod
-    }
+    my $ld = "package $pkg; use IRC::Toolkit::$mod; 1;";
+    eval $ld and not $@ or warn "$@\n" and push @failed, $mod;
   }
   confess "Failed to import ".join ' ', @failed if @failed;
   1
@@ -50,7 +45,7 @@ IRC::Toolkit - Useful IRC objects and utilities
   ##  (Case, Colors, CTCP, ISupport, Masks, Modes, Parser)
   use IRC::Toolkit;
 
-  ## Import specific modules:
+  ## Import a list of modules:
   use IRC::Toolkit qw/
     CTCP
     Masks
@@ -69,15 +64,15 @@ documentation, below.
 Modules that export functions use L<Exporter::Tiny>, which is quite flexible;
 see the L<Exporter::Tiny> docs for details.
 
-L<IRC::Message::Object>; objects representing incoming or outgoing IRC events
+L<IRC::Message::Object>; Objects representing incoming or outgoing IRC events
 
-L<IRC::Mode::Single>; objects representing a single mode change
+L<IRC::Mode::Single>; Objects representing a single mode change
 
-L<IRC::Mode::Set>; objects representing a set of mode changes
+L<IRC::Mode::Set>; Objects representing a set of mode changes
 
 L<IRC::Toolkit::Case>; RFC-compliant case folding tools
 
-L<IRC::Toolkit::Colors>; Color/format interpolation in strings
+L<IRC::Toolkit::Colors>; Color/format code interpolation & removal
 
 L<IRC::Toolkit::CTCP>; CTCP quoting and extraction tools
 
@@ -91,7 +86,7 @@ L<IRC::Toolkit::Numerics>; IRC numerics translation to/from RPL or ERR names
 
 L<IRC::Toolkit::Parser>; Functional interface to L<POE::Filter::IRCv3>
 
-L<IRC::Toolkit::TS6>; Produce TS6 IDs
+L<IRC::Toolkit::TS6>; Produce sequential TS6 IDs
 
 L<IRC::Toolkit::Role::CaseMap>; A Role for classes that track IRC casemapping
 settings
