@@ -1,6 +1,6 @@
 package IRC::Toolkit::Case;
 {
-  $IRC::Toolkit::Case::VERSION = '0.087000';
+  $IRC::Toolkit::Case::VERSION = '0.088001';
 }
 use strictures 1;
 no warnings 'once';
@@ -139,7 +139,7 @@ strings accordingly, you may also want to see L<IRC::Toolkit::Role::CaseMap>.
 =head2 rfc1459 operator
 
 The infix operator C<|rfc1459|> is provided as a convenience for string
-comparison using RFC1459 rules:
+comparison (using RFC1459 rules):
 
   if ($first |rfc1459| $second) { ... }
   # Same as:
@@ -184,4 +184,6 @@ Jon Portnoy <avenj@cobaltirc.org>
 
 Inspired by L<IRC::Utils>, copyright Chris Williams, Hinrik et al
 
+Licensed under the same terms as Perl.
+
 =cut
